
# Type: enabled by


holds between a process and a physical entity, where the physical entity executes the process

URI: [biolink:enabled_by](https://w3id.org/biolink/vocab/enabled_by)


## Domain and Range

[Occurrent](Occurrent.md) ->  <sub>0..*</sub> [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)

## Parents

 *  is_a: [has participant](has_participant.md)

## Children

 *  [molecular activity➞enabled by](molecular_activity_enabled_by.md)

## Used by

 * [BiologicalProcess](BiologicalProcess.md)
 * [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)
 * [MolecularActivity](MolecularActivity.md)
 * [Pathway](Pathway.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002333 |
| **In Subsets:** | | translator_minimal |

